import sys

from botocore.session import Session

from .aws_auth import AWSRequestsAuth

if sys.version_info >= (3, 8):
    from typing_extensions import TypedDict
else:
    from typing import TypedDict

class Credentials(TypedDict):
    aws_access_key: str
    aws_secret_access_key: str
    aws_token: str

def get_credentials(credentials_obj: Session | None = ...): ...

class BotoAWSRequestsAuth(AWSRequestsAuth):
    def __init__(self, aws_host: str, aws_region: str, aws_service: str): ...



import sys
from typing import overload

if sys.version_info >= (3, 8):
    from typing_extensions import TypedDict
else:
    from typing import TypedDict

from requests import PreparedRequest
from requests.auth import AuthBase

AwsAuthHeader = TypedDict(
    "AwsAuthHeader",
    {
        "Authorization": str,
        "x-amz-date": str,
        "x-amz-content-sha256": bytes,
    },
)

AwsAuthHeaderWithToken = TypedDict(
    "AwsAuthHeaderWithToken",
    {
        "Authorization": str,
        "x-amz-date": str,
        "x-amz-content-sha256": bytes,
        "X-Amz-Security-Token": str,
    },
)

def sign(key: bytes, message: str) -> bytes: ...
def getSignatureKey(key: str, dateStamp: str, regionName: str, serviceName: str) -> bytes: ...

class AWSRequestsAuth(AuthBase):
    aws_access_key: str
    aws_secret_access_key: str
    aws_host: str
    aws_region: str
    service: str
    aws_token: str | None = ...

    def __init__(
        self,
        aws_access_key: str,
        aws_secret_access_key: str,
        aws_host: str,
        aws_region: str,
        aws_service: str,
        aws_token: str | None = ...,
    ) -> None: ...
    def get_aws_request_headers_handler(self, r: PreparedRequest): ...
    @overload
    def get_aws_request_headers(
        self, r: PreparedRequest, aws_access_key: str, aws_secret_access_key: str, aws_token: None
    ) -> AwsAuthHeader: ...
    @overload
    def get_aws_request_headers(
        self, r: PreparedRequest, aws_access_key: str, aws_secret_access_key: str, aws_token: str
    ) -> AwsAuthHeaderWithToken: ...
    @classmethod
    def get_canonical_path(cls, r: PreparedRequest) -> str: ...
    @classmethod
    def get_canonical_querystring(cls, r: PreparedRequest) -> str: ...



import os

from setuptools import setup


def find_stubs(package):
    stubs = []
    for root, dirs, files in os.walk(package):
        for file in files:
            path = os.path.join(root, file).replace(package + os.sep, "", 1)
            stubs.append(path)
    return {package: stubs}


with open("README.md") as f:
    readme = f.read()

setup(
    name="aws_requests_auth-stubs",
    version="0.4.3.2",
    author="Yonatan Greenfeld",
    author_email="yonatangreenfeld97@gmail.com",
    description="PEP 561 stubs for aws-requests-auth",
    long_description=readme,
    long_description_content_type="text/markdown",
    url="https://github.com/YonatanGreenfeld/aws-requests-auth-stubs",
    license="MIT",
    packages=["aws_requests_auth-stubs"],
    python_requires=">=3.7",
    # PEP 561 requires these
    install_requires=[
        "aws-requests-auth>=0.4.3",
        "botocore-stubs>=1.27.42",
        "types-requests>=2.25.0",
        'typing_extensions>=3.7.4; python_version<"3.8"',
    ],
    package_data=find_stubs("aws_requests_auth-stubs"),
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Typing :: Typed",
    ],
)
